@@ -1,16 +1,14 @@
-# $Id: Factor.pm,v 0.14 2004/01/13 15:01:06 sts Exp $
+# $Id: Factor.pm,v 0.15 2004/01/13 15:01:06 sts Exp $
 
 package Math::Factor;
 
 use 5.006;
+use base qw(Exporter);
 use integer;
 use strict 'vars';
 use warnings;
 
-our $VERSION = '0.14';
-
-use Exporter;
-use base qw(Exporter);
+our $VERSION = '0.15';
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs_factor,
      @subs_match, @subs);
@@ -88,12 +86,12 @@ certain numbers may be entirely disabled by supplying *. 1-$ is equivalent to *.
 =cut
 
 sub factor {
-    my $data_ref = $_[0];
+    my $numbers = $_[0];
     croak q~usage: factor (\@numbers)~
-      unless @$data_ref && ref $data_ref eq 'ARRAY';
+      unless @$numbers && ref $numbers eq 'ARRAY';
 
     my (%factor, $number, $i, $limit);
-    foreach (@$data_ref) {
+    foreach (@$numbers) {
         $i = 0; 
         if (ref $_) { 
 	    $number = $$_[0];
@@ -134,20 +132,20 @@ ones by $$matches{9}[1][0] and $$matches{9}[1][1], and so on.
 =cut
 
 sub match {
-    my $data_ref = $_[0];
+    my $factors = $_[0];
     croak q~usage: match ($factors)~
-      unless %$data_ref && ref $data_ref eq 'HASH';
+      unless %$factors && ref $factors eq 'HASH';
 
-    my (%match, $i);
-    foreach (keys %$data_ref) {
+    my (%matches, $i);
+    foreach (keys %$factors) {
         $i = 0;
-        my @cmp = my @base = @{$$data_ref{$_}};
+        my @cmp = my @base = @{$$factors{$_}};
         foreach my $base (@base) {
             foreach my $cmp (@cmp) {
                 if ($cmp >= $base) {
                     if ($base * $cmp == $_) {
-                        $match{$_}[$i][0] = $base;
-                        $match{$_}[$i][1] = $cmp;
+                        $matches{$_}[$i][0] = $base;
+                        $matches{$_}[$i][1] = $cmp;
                         $i++;
                     }
                 }
@@ -155,7 +153,7 @@ sub match {
         }
     }
 
-    return \%match;
+    return \%matches;
 }
 
 =head2 each_factor
@@ -173,12 +171,12 @@ after usage of each_factor().
 =cut
 
 sub each_factor {
-    my ($number, $data_ref) = @_;
+    my ($number, $factors) = @_;
     croak q~usage: each_factor ($number, $factors)~
-      unless $number && ref $data_ref eq 'HASH';
+      unless $number && ref $factors eq 'HASH';
 
     unless (${__PACKAGE__."::each_factor_$number"}) {
-        @{__PACKAGE__."::each_factor_$number"} = @{$$data_ref{$number}};
+        @{__PACKAGE__."::each_factor_$number"} = @{$$factors{$number}};
         ${__PACKAGE__."::each_factor_$number"} = 1;
     }
 
@@ -203,19 +201,19 @@ after usage of each_match().
 =cut
 
 sub each_match {
-    my ($number, $data_ref) = @_;
+    my ($number, $matches) = @_;
     croak q~usage: each_match ($number, $matches)~
-      unless $number && ref $data_ref eq 'HASH';
+      unless $number && ref $matches eq 'HASH';
 
     unless (${__PACKAGE__."::each_match_$number"}) {
-        @{__PACKAGE__."::each_match_$number"} = @{$$data_ref{$number}};
+        @{__PACKAGE__."::each_match_$number"} = @{$$matches{$number}};
         ${__PACKAGE__."::each_match_$number"} = 1;
     }
 
     if (@{__PACKAGE__."::each_match_$number"} && wantarray) {
         my @match = (${__PACKAGE__."::each_match_$number"}[0][0], 
 	  ${__PACKAGE__."::each_match_$number"}[0][1]);
-        splice (@{__PACKAGE__."::each_match_$number"}, 0, 1);
+        splice @{__PACKAGE__."::each_match_$number"}, 0, 1;
         return @match;
     }
     else { ${__PACKAGE__."::each_match_$number"} = 0; return }
@@ -224,7 +222,7 @@ sub each_match {
 1;
 __END__
 
-=head2 EXPORT
+=head1 EXPORT
 
 C<factor(), match(), each_factor(), each_match()> upon request.
 
